import {Grid, Typography, TextField, Box} from '@mui/material';
import { MuiTelInput } from 'mui-tel-input'


export const DadosPessoais = ( {formik}: any ) => {

  const handleChange = (newValue: string) => {
    formik.setFieldValue( 'telemovelDP', newValue );
  };

  return (
    <Box>
      <Typography variant="h6" gutterBottom>
        Dados Pessoais
      </Typography>
      <Grid container spacing={3}>
        <Grid item xs={12} sm={6}>
          <TextField
            {...formik.getFieldProps('empresa')}
            required
            id="empresa"
            name="empresa"
            label="Nome/Empresa"
            fullWidth
            variant="standard"
            error={formik.touched.empresa && Boolean(formik.errors.empresa)}
            helperText={formik.touched.empresa && formik.errors.empresa}
          />
        </Grid>
        <Grid item xs={12} sm={6}>
          <TextField
            {...formik.getFieldProps('nif')}
            type='number'
            id="nif"
            name="nif"
            label="NIF/NIPC"
            fullWidth
            variant="standard"
          />
        </Grid>
        <Grid item xs={12} sm={12}>
          <TextField
            {...formik.getFieldProps('representante')}
            required
            type='text'
            id="representante"
            name="representante"
            label="Nome do representante legal (empresa)"
            fullWidth
            variant="standard"
            error={formik.touched.representante && Boolean(formik.errors.representante)}
            helperText={formik.touched.representante && formik.errors.representante}
          />
        </Grid>
        <Grid item xs={12} sm={6}>
          <MuiTelInput
            {...formik.getFieldProps('telemovelDP')}
            required
            id="telemovelDP"
            label="Telemóvel"
            value={formik.values.telemovelDP}
            fullWidth
            onChange={handleChange}
            variant="standard"
            error={formik.touched.telemovelDP && Boolean(formik.errors.telemovelDP)}
            helperText={formik.touched.telemovelDP && formik.errors.telemovelDP}
          />
        </Grid>
        <Grid item xs={12} sm={6}>
          <TextField
            {...formik.getFieldProps('emailDP')}
            required
            type='email'
            id="emailDP"
            name="emailDP"
            label="Email"
            fullWidth
            variant="standard"
            error={formik.touched.emailDP && Boolean(formik.errors.emailDP)}
            helperText={formik.touched.emailDP && formik.errors.emailDP}
          />
        </Grid>
        <Grid item xs={12} sm={6}>
          <TextField
            {...formik.getFieldProps('morada')}
            type='text'
            id="morada"
            name="morada"
            label="Morada"
            fullWidth
            variant="standard"
          />
        </Grid>
        <Grid item xs={12} sm={6}>
          <TextField
            {...formik.getFieldProps('andar')}
            type='number'
            id="andar"
            name="andar"
            label="Andar/Nº/Bloco"
            fullWidth
            variant="standard"
          />
        </Grid>
        <Grid item xs={12} sm={4}>
          <TextField
            {...formik.getFieldProps('pais')}
            type='text'
            id="pais"
            name="pais"
            label="País"
            fullWidth
            variant="standard"
          />
        </Grid>
        <Grid item xs={12} sm={4}>
          <TextField
            {...formik.getFieldProps('cidade')}
            type='text'
            id="cidade"
            name="cidade"
            label="Cidade"
            fullWidth
            variant="standard"
          />
        </Grid>
        <Grid item xs={12} sm={4}>
          <TextField
            {...formik.getFieldProps('codigoPostal')}
            type='number'
            id="codigoPostal"
            name="codigoPostal"
            label="Código Postal"
            fullWidth
            autoComplete="shipping country"
            variant="standard"
          />
        </Grid>
      </Grid>
    </Box>
  );
};
